@@ -242,14 +242,14 @@ from copy import deepcopy
 from pprint import pformat
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
-from ae.base import norm_line_sep, norm_name                                                # type: ignore
-from ae.files import read_file_text, write_file_text                                        # type: ignore
-from ae.i18n import get_f_string                                                            # type: ignore
-from ae.core import DEBUG_LEVEL_VERBOSE                                                     # type: ignore
-from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action               # type: ignore
+from ae.base import norm_line_sep, norm_name                                                    # type: ignore
+from ae.files import read_file_text, write_file_text                                            # type: ignore
+from ae.i18n import get_f_string                                                                # type: ignore
+from ae.core import DEBUG_LEVEL_VERBOSE                                                         # type: ignore
+from ae.gui_app import id_of_flow, flow_action, flow_key, flow_path_strip, replace_flow_action  # type: ignore
 
 
-__version__ = '0.1.40'
+__version__ = '0.1.43'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -399,15 +399,15 @@ class LiszDataMixin(ABC):
     # abstract methods
     # the gui_app methods are not really abstract (nor callable via super()) but declared here for proper type checking
     @abstractmethod
-    def call_method(self, method: str, *args, **kwargs) -> Any:
-        """ call method of this instance (ae.gui_app.MainAppBase method). """
+    def call_method(self, callback: Union[Callable, str], *args, **kwargs) -> Any:
+        """ call callable or method of this instance (ae.core.AppBase method). """
 
     @abstractmethod
-    def call_method_delayed(self, delay: float, method: str, *args, **kwargs) -> Any:
-        """ call method of this instance delayed (ae.gui_app.MainAppBase method). """
+    def call_method_delayed(self, delay: float, callback: Union[Callable, str], *args, **kwargs) -> Any:
+        """ delayed call callable or method of this instance (ae.gui_help.HelpAppBase). """
 
     @abstractmethod
-    def change_app_state(self, state_name: str, state_value: Any, send_event: bool = True):
+    def change_app_state(self, app_state_name: str, state_value: Any, send_event: bool = True, old_name: str = ''):
         """ add debug sound on each state change/save (ae.gui_app.MainAppBase method). """
 
     @abstractmethod
@@ -418,10 +418,6 @@ class LiszDataMixin(ABC):
     def flow_path_action(self, flow_path: Optional[List[str]] = None, path_index: int = -1) -> str:
         """ determine the action of the last/newest entry in the flow_path (ae.gui_app.MainAppBase method). """
 
-    @abstractmethod
-    def flow_path_strip(self, flow_path: List[str]) -> List[str]:
-        """ return flow_path copy with all non-enter actions stripped from the end. """
-
     @abstractmethod
     def play_sound(self, sound_name: str):
         """ play audio/sound file (ae.gui_app.MainAppBase method). """
@@ -605,7 +601,7 @@ class LiszDataMixin(ABC):
         """
         if not node:
             node = self.flow_path_node(flow_path)
-        flow_path = self.flow_path_strip(flow_path)
+        flow_path = flow_path_strip(flow_path)
         file_name = NODE_FILE_PREFIX + (norm_name(flow_key(flow_path[-1])) if flow_path else
                                         FLOW_PATH_ROOT_ID) + NODE_FILE_EXT
 
@@ -729,7 +725,7 @@ class LiszDataMixin(ABC):
             deep += 1
 
         # add sub paths, find start node from the end of current flow path, skipping opt. open_flow_path_jumper flow id
-        deeper_flow_path = self.flow_path_strip(self.flow_path)
+        deeper_flow_path = flow_path_strip(self.flow_path)
         append_nodes(self.current_node_items)
 
         return paths
@@ -942,10 +938,10 @@ class LiszDataMixin(ABC):
         leaf_names = self.sub_item_ids(node=node, recursive=recursive)
         leaf_count = len(leaf_names)
         selected_leaf_names = self.sub_item_ids(node=node, hide_sel_val=False, recursive=recursive)
-        selected_leaf_count = len(selected_leaf_names)          # noqa: F841
+        selected_leaf_count = len(selected_leaf_names)          # noqa: F841 # pylint: disable=possibly-unused-variable
         unselected_leaf_names = self.sub_item_ids(node=node, hide_sel_val=True, recursive=recursive)
-        unselected_leaf_count = len(unselected_leaf_names)      # noqa: F841
-        node_count = count - leaf_count                         # noqa: F841
+        unselected_leaf_count = len(unselected_leaf_names)      # noqa: F841 # pylint: disable=possibly-unused-variable
+        node_count = count - leaf_count                         # noqa: F841 # pylint: disable=possibly-unused-variable
 
         return {k: v for k, v in locals().items() if not what or k in what}
 
